@@ -31,8 +31,8 @@ def cli(url: str, update: bool, limit: int) -> None:
 
     # If specified ..
     if update:
-        # .. update database
-        obj.update(True)
+        # .. force database update
+        obj.update(0)
 
     # Create application
     app = GoatPieApp
@@ -42,4 +42,4 @@ def cli(url: str, update: bool, limit: int) -> None:
     app.limit = limit
 
     # Run!
-    app.run(title='"Goatcounter" analytics', log=os.path.join(base_dir, 'debug.log'))
+    app.run(title='"Goatcounter" analytics', log=os.path.join(base_dir, 'app.log'))
